/*
 * Dashboard Style
 */
.logo {
    font-family: 'Stardos Stencil', cursive;
    font-size: 1.5em;
}

.table-fixed {
    table-layout: fixed;
}

.table-fixed td {
    overflow: hidden;
    text-overflow: ellipsis;
}

.copy-button {
    padding: 0;
    border: none;
    background: none;
}

.copy-button-hover {
    color: #31708f;
}

.copy-button:active, .copy-button:focus {
    outline: none;
    border: none;
}

.copy-button:before {
    font-family: 'Pe-icon-7-stroke';
    font-size: 1.33333333em;
    vertical-align: -15%;
    content: '\e665';
}

.file-browser {
    padding: 0;
    border: none;
    background: none;
    color: inherit;
}

.file-browser:hover {
    color: #31708f;
    text-decoration: none;
}

.file-browser:active, .file-browser:focus {
    outline: none;
    border: none;
}

.file-browser:before {
    font-family: 'Pe-icon-7-stroke';
    font-size: 1.33333333em;
    vertical-align: -15%;
    content: '\e653';
}

.file-list {
    height: 100vh;
    overflow: scroll;
}

.file-list ul {
    list-style: none;
}

.file-list ul:first-child {
    padding-left: 1em;
}

.file-list .directory {
    cursor: pointer;
}

.file-list .directory .collapsed:before {
    font-family: 'FontAwesome';
    font-size: 1.1em;
    vertical-align: -15%;
    padding-right: .2em;
    content: '\f114';
}

.file-list .directory:before {
    font-family: 'FontAwesome';
    font-size: 1.1em;
    vertical-align: -15%;
    padding-right: .2em;
    content: '\f115';
}

.file-list ul li:before {
    font-family: 'Pe-icon-7-stroke';
    font-size: 1.2em;
    vertical-align: -15%;
    padding-right: .2em;
    content: '\e656';
}

/*
 * Sticky Footer
 */
.footer {
    position: absolute;
    bottom: 0;
    width: 100%;
    height: 150px;
}

a img {
    border: none;
}

.footer_icon {
    height: 68px;
}

/*
 * Bootstrap overrides
 */
html {
    font-family: sans-serif !important;
    -ms-text-size-adjust: 100%;
    -webkit-text-size-adjust: 100%;
    position: relative;
    min-height: 100%;
}

body {
    margin: 0;
    margin: 0;
    margin-bottom: 150px;
    font-size: 15px !important;
}

.row {
    margin-bottom: 1.5em;
}

.breadcrumb li {
    margin-bottom: 0px;
    vertical-align: middle;
}

/*
 * jQuery UI CSS overrides
 */
.ui-widget {
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
    font-size: 1em;
}

.ui-widget-content a {
    color: #337ab7 !important;
}

.ui-corner-all, .ui-corner-top, .ui-corner-left, .ui-corner-tl {
    -moz-border-radius-topleft: 0px;
    -webkit-border-top-left-radius: 0px;
    -khtml-border-top-left-radius: 0px;
    border-top-left-radius: 0px;
}

.ui-corner-all, .ui-corner-top, .ui-corner-right, .ui-corner-tr {
    -moz-border-radius-topright: 0px;
    -webkit-border-top-right-radius: 0px;
    -khtml-border-top-right-radius: 0px;
    border-top-right-radius: 0px;
}

.ui-corner-all, .ui-corner-bottom, .ui-corner-left, .ui-corner-bl {
    -moz-border-radius-bottomleft: 0px;
    -webkit-border-bottom-left-radius: 0px;
    -khtml-border-bottom-left-radius: 0px;
    border-bottom-left-radius: 0px;
}

.ui-corner-all, .ui-corner-bottom, .ui-corner-right, .ui-corner-br {
    -moz-border-radius-bottomright: 0px;
    -webkit-border-bottom-right-radius: 0px;
    -khtml-border-bottom-right-radius: 0px;
    border-bottom-right-radius: 0px;
}

/*
 * Data tables CSS overrides
 */
.dataTables_wrapper .fg-toolbar {
    padding: .2em;
}

.dataTables_wrapper .dataTables_info {
    padding: .25em !important;
}

.dataTables_paginate .fg-button {
    padding: .25em !important;
}

table.dataTable th {
    text-align: center;
    vertical-align: middle;
}

table.dataTable tr.odd {
    background-color: #dfd;
}

table.dataTable tr.even {
    background-color: #efe;
}

/*
 * Successful
 */
table.dataTable tr.odd.successful {
    background-color: #ddffdd;
}

table.dataTable tr.even.successful {
    background-color: #eeffee;
}

tr.odd.successful td.sorting_1 {
    background-color: #c4ffc4 !important;
}

tr.even.successful td.sorting_1 {
    background-color: #d5ffd5 !important;
}

/*
 * Running
 */
table.dataTable tr.odd.running {
    background-color: #ddddff;
}

table.dataTable tr.even.running {
    background-color: #eeeeff;
}

tr.odd.running td.sorting_1 {
    background-color: #c4c4ff !important;
}

tr.even.running td.sorting_1 {
    background-color: #d5d5ff !important;
}

/*
 * Failed
 */
table.dataTable tr.odd.failed {
    background-color: #ffdddd;
}

table.dataTable tr.even.failed {
    background-color: #ffeeee;
}

tr.odd.failed td.sorting_1 {
    background-color: #ffc4c4 !important;
}

tr.even.failed td.sorting_1 {
    background-color: #ffd5d5 !important;
}

/*
 * Failing
 */
table.dataTable tr.odd.failing {
    background-color: #fff2e3;
}

table.dataTable tr.even.failing {
    background-color: #fff9f3;
}

tr.odd.failing td.sorting_1 {
    background-color: #ffe0c2 !important;
}

tr.even.failing td.sorting_1 {
    background-color: #fff0e0 !important;
}

/*
 * Archived
 */
table.dataTable tr.odd.archived {
    background-color: #e0e0e0;
}

table.dataTable tr.even.archived {
    background-color: #f0f0f0;
}

tr.odd.archived td.sorting_1 {
    background-color: #c0c0c0 !important;
}

tr.even.archived td.sorting_1 {
    background-color: #d0d0d0 !important;
}
