<footer class="footer">
    <div class="container-fluid">
        <div class="row text-center">
            <a href="http://pegasus.isi.edu"><img id="stampede_image"
                                                  src="{{ url_for ('static', filename='images/footer/stampede.png') }}"
                                                  title="STAMPEDE" class="footer_icon"/></a>
            <a href="http://pegasus.isi.edu"><img id="pegasus_image"
                                                  src="{{ url_for ('static', filename='images/footer/pegasus.jpg') }}"
                                                  title="Pegasus Workflow Management System" class="footer_icon"/></a>
            <a href="http://www.isi.edu"><img id="isi_image"
                                              src="{{ url_for ('static', filename='images/footer/isi.png') }}"
                                              title="Information Sciences Institute" class="footer_icon"/></a>
            <a href="http://www.usc.edu"><img id="usc_image"
                                              src="{{ url_for ('static', filename='images/footer/usc.png') }}"
                                              title="University of Southern California" class="footer_icon"/></a>
        </div>
        <div class="row help-block text-center">
            <p>Copyright <i class="fa fa-copyright fa-lg"></i> 2015 University of Southern California</p>

            <p>
                <span class="pe-7s-mail fa-lg"> </span> <a href="mailto:pegasus-users@isi.edu">pegasus-users@isi.edu</a>
            </p>
        </div>
    </div>
</footer>
