<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{% block title %}{% endblock %}</title>
    <link rel="shortcut icon" href="{{ url_for ('static', filename='favicon.ico') }}">

    {% block head %}
    <!-- Stylesheets -->
    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootstrap/3.3.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css">
    <link rel='stylesheet' href='//fonts.googleapis.com/css?family=Stardos+Stencil'>
    <link rel="stylesheet" href="{{ url_for ('static', filename='css/style.css') }}"/>
    <link rel="stylesheet" href="{{ url_for ('static', filename='css/pe-icon-7-stroke.css') }}"/>
    {% block css_includes %}{% endblock %}
    {% endblock %}

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
    <script src="//oss.maxcdn.com/html5shiv/3.7.2/html5shiv.min.js"></script>
    <script src="//oss.maxcdn.com/respond/1.4.2/respond.min.js"></script>
    <![endif]-->
</head>
<body>
{% include "header.html" %}
<div class="container">
    <section class="row">
        <h1><span class="pe-7s-attention fa-lg text-danger"></span> {% block title_header %}{% endblock %}</h1>
    </section>
    {% block content %}{% endblock %}
</div>
<!-- JavaScript -->
<script src="//code.jquery.com/jquery-2.1.3.min.js" integrity="sha256-ivk71nXhz9nsyFDoYoGf2sbjrR9ddh+XDkCcfZxjvcM=" crossorigin="anonymous"></script>
<script type="text/javascript" src="//maxcdn.bootstrapcdn.com/bootstrap/3.3.2/js/bootstrap.min.js"></script>
{% block javascript_includes %}{% endblock %}
{% block javascript_init %}{% endblock %}
</body>
</html>
