{% extends "base-error.html" %}
{% block title %}Workflow - Not found{% endblock %}
{% block title_header %}Workflow Database Not Found{% endblock %}
{% block navigation_bar %}-{% endblock %}
{% block content %}
<section class="row">
    <div class="col-xs-12">
        <h3>Possible Reasons</h3>
        <ul>
            <li>
                Workflow submit directory was moved or deleted from the file system.
            </li>
        </ul>
    </div>
</section>
{% endblock %}
